==> jc-1.4.0.tar.gz: java/beans/PropertyVetoException.h <==
// public class java.beans.PropertyVetoException

// class file dependencies
// @dep_class 4c201d8d34db6ac9 java_beans_PropertyVetoException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_beans_PropertyVetoException_H_
#define _JC_java_beans_PropertyVetoException_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_PropertyVetoException$sub_refs	_jc_java_beans_PropertyVetoException$sub_refs;
typedef struct _jc_java_beans_PropertyVetoException$sub_nonrefs	_jc_java_beans_PropertyVetoException$sub_nonrefs;
typedef struct _jc_java_beans_PropertyVetoException$refs	_jc_java_beans_PropertyVetoException$refs;
typedef struct _jc_java_beans_PropertyVetoException$nonrefs	_jc_java_beans_PropertyVetoException$nonrefs;
typedef struct _jc_java_beans_PropertyVetoException$object	_jc_java_beans_PropertyVetoException$object;

typedef struct _jc_java_beans_PropertyVetoException$fields_struct	_jc_java_beans_PropertyVetoException$fields_struct;
typedef const struct _jc_java_beans_PropertyVetoException$vmethods	_jc_java_beans_PropertyVetoException$vmethods;
typedef const struct _jc_java_beans_PropertyVetoException$vtable	_jc_java_beans_PropertyVetoException$vtable;
typedef const struct _jc_java_beans_PropertyVetoException$vtype	_jc_java_beans_PropertyVetoException$vtype;

// Class fields structure
struct _jc_java_beans_PropertyVetoException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_PropertyVetoException$fields_struct _jc_java_beans_PropertyVetoException$class_fields;

// Constructors
extern void _jc_java_beans_PropertyVetoException$method$_init$7e30f6f701c58e11(_jc_env *, struct _jc_java_beans_PropertyVetoException$object *, struct _jc_java_lang_String$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual methods
extern struct _jc_java_beans_PropertyChangeEvent$object *_jc_java_beans_PropertyVetoException$method$getPropertyChangeEvent$fb1c79c90425d90b(_jc_env *, struct _jc_java_beans_PropertyVetoException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_PropertyVetoException$method_info$getPropertyChangeEvent$fb1c79c90425d90b;

// Virtual methods structure
struct _jc_java_beans_PropertyVetoException$vmethods {
	struct _jc_java_beans_PropertyChangeEvent$object	*(*getPropertyChangeEvent$fb1c79c90425d90b)(_jc_env *, struct _jc_java_beans_PropertyVetoException$object *);
};

// Vtable
struct _jc_java_beans_PropertyVetoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_beans_PropertyVetoException$vmethods	java_beans_PropertyVetoException;
};

// Vtype
struct _jc_java_beans_PropertyVetoException$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyVetoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyVetoException$sub_refs {
	struct _jc_java_beans_PropertyChangeEvent$object	*evt;
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyVetoException$refs {
    _jc_java_beans_PropertyVetoException$sub_refs	java_beans_PropertyVetoException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyVetoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyVetoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_beans_PropertyVetoException$sub_nonrefs	java_beans_PropertyVetoException;
};

// Object instance structure
struct _jc_java_beans_PropertyVetoException$object {
	_jc_java_beans_PropertyVetoException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyVetoException$vtype	*vtype;
	_jc_java_beans_PropertyVetoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyVetoException$vtype _jc_java_beans_PropertyVetoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyVetoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyVetoException$class_object;

#endif	/* _JC_java_beans_PropertyVetoException_H_ */

==> jc-1.4.6.tar.gz: java/beans/PropertyVetoException.h <==
// public class java.beans.PropertyVetoException

// class file dependencies
// @dep_class 4c201d8d34db6ac9 java_beans_PropertyVetoException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_beans_PropertyVetoException_H_
#define _JC_java_beans_PropertyVetoException_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_PropertyVetoException$sub_refs	_jc_java_beans_PropertyVetoException$sub_refs;
typedef struct _jc_java_beans_PropertyVetoException$sub_nonrefs	_jc_java_beans_PropertyVetoException$sub_nonrefs;
typedef struct _jc_java_beans_PropertyVetoException$refs	_jc_java_beans_PropertyVetoException$refs;
typedef struct _jc_java_beans_PropertyVetoException$nonrefs	_jc_java_beans_PropertyVetoException$nonrefs;
typedef struct _jc_java_beans_PropertyVetoException$object	_jc_java_beans_PropertyVetoException$object;

typedef struct _jc_java_beans_PropertyVetoException$fields_struct	_jc_java_beans_PropertyVetoException$fields_struct;
typedef const struct _jc_java_beans_PropertyVetoException$vmethods	_jc_java_beans_PropertyVetoException$vmethods;
typedef const struct _jc_java_beans_PropertyVetoException$vtable	_jc_java_beans_PropertyVetoException$vtable;
typedef const struct _jc_java_beans_PropertyVetoException$vtype	_jc_java_beans_PropertyVetoException$vtype;

// Class fields structure
struct _jc_java_beans_PropertyVetoException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_PropertyVetoException$fields_struct _jc_java_beans_PropertyVetoException$class_fields;

// Constructors
extern void _jc_java_beans_PropertyVetoException$method$_init$7e30f6f701c58e11(_jc_env *, struct _jc_java_beans_PropertyVetoException$object *, struct _jc_java_lang_String$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_beans_PropertyChangeEvent$object *_jc_java_beans_PropertyVetoException$method$getPropertyChangeEvent$fb1c79c90425d90b(_jc_env *, struct _jc_java_beans_PropertyVetoException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_PropertyVetoException$method_info$getPropertyChangeEvent$fb1c79c90425d90b;

// Virtual methods structure
struct _jc_java_beans_PropertyVetoException$vmethods {
	struct _jc_java_beans_PropertyChangeEvent$object	*(*getPropertyChangeEvent$fb1c79c90425d90b)(_jc_env *, struct _jc_java_beans_PropertyVetoException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_PropertyVetoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_beans_PropertyVetoException$vmethods	java_beans_PropertyVetoException;
};

// Vtype
struct _jc_java_beans_PropertyVetoException$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyVetoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyVetoException$sub_refs {
	struct _jc_java_beans_PropertyChangeEvent$object	*evt;
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyVetoException$refs {
    _jc_java_beans_PropertyVetoException$sub_refs	java_beans_PropertyVetoException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyVetoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyVetoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_beans_PropertyVetoException$sub_nonrefs	java_beans_PropertyVetoException;
};

// Object instance structure
struct _jc_java_beans_PropertyVetoException$object {
	_jc_java_beans_PropertyVetoException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyVetoException$vtype	*vtype;
	_jc_java_beans_PropertyVetoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyVetoException$vtype _jc_java_beans_PropertyVetoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyVetoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyVetoException$class_object;

#endif	/* _JC_java_beans_PropertyVetoException_H_ */
